@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """ __init__.py
-baseobjects provides several base classes.
+baseobjects provides several base classes and tools.
 """
 # Package Header #
-from .__header__ import *
+from .header import *
 
 # Header #
 __author__ = __author__
@@ -15,8 +15,8 @@ __email__ = __email__
 
 # Imports #
 # Local Packages #
-from .baseobject import BaseObject, search_sentinel
-from .basemeta import BaseMeta
-from .cachingtools import *
+from .bases import *
+from .metaclasses import *
 from .objects import *
+from .cachingtools import *
 from .warnings import TimeoutWarning
