@@ -4,7 +4,7 @@
 An abstract class which creates properties for this class automatically.
 """
 # Package Header #
-from ..__header__ import *
+from ..header import *
 
 # Header #
 __author__ = __author__
@@ -15,16 +15,16 @@ __email__ = __email__
 
 # Imports #
 # Standard Libraries #
+from collections.abc import Callable
+from typing import Any
 
 # Third-Party Packages #
 
 # Local Packages #
-from ..baseobject import BaseObject
-from .meta import CachingObjectMeta
-from .timedsinglecache import TimedSingleCache
-from .timedkeylesscache import TimedKeylessCache
-from .timedcache import TimedCache
-from .basetimedcache import BaseTimedCache
+from ..types_ import AnyCallable
+from ..bases import BaseObject
+from .metaclasses import CachingObjectMeta
+from .caches import TimedSingleCache, TimedKeylessCache, TimedCache, BaseTimedCache
 
 
 # Definitions #
@@ -34,7 +34,7 @@ class CachingObjectMethod(BaseTimedCache):
 
     # Instance Methods #
     # Object Calling
-    def caching_call(self, *args, **kwargs):
+    def caching_call(self, *args: Any, **kwargs: Any) -> Any:
         """Calls the caching function, clears the cache at certain time, and allows the owning object to override.
 
         Args:
@@ -44,20 +44,24 @@ class CachingObjectMethod(BaseTimedCache):
         Returns:
             The result or the caching_method.
         """
+        # Get the object to operate on.
         if self.__self__ is not None:
             obj = self.__self__
         else:
             obj = args[0]
 
+        # Clear cache if condition is met or not caching.
         if self.clear_condition() or not obj.is_cache:
             self.clear_cache()
 
+        # Use caching method if allowed.
         if obj.is_cache:
             return self.caching_method(obj, *args, **kwargs)
+        # Run normal method if not allowed.
         else:
             return self.__func__(obj, *args, **kwargs)
 
-    def clearing_call(self, *args, **kwargs):
+    def clearing_call(self, *args: Any, **kwargs: Any) -> Any:
         """Clears the cache then calls the caching function and allows the owning object to override.
 
         Args:
@@ -67,31 +71,38 @@ class CachingObjectMethod(BaseTimedCache):
         Returns:
             The result or the caching_method.
         """
+        # Get the object to operate on.
         if self.__self__ is not None:
             obj = self.__self__
         else:
             obj = args[0]
 
+        # Clear Cache
         self.clear_cache()
 
+        # Use caching method if allowed.
         if obj.is_cache:
             return self.caching_method(obj, *args, **kwargs)
+        # Run normal method if not allowed.
         else:
             return self.__func__(obj, *args, **kwargs)
 
 
 class TimedSingleCacheMethod(TimedSingleCache, CachingObjectMethod):
     """A mixin class that implements both TimedSingleCache and CachingObjectMethod"""
+
     pass
 
 
 class TimedKeylessCacheMethod(TimedKeylessCache, CachingObjectMethod):
     """A mixin class that implements both TimedKeylessCache and CachingObjectMethod"""
+
     pass
 
 
 class TimedCacheMethod(TimedCache, CachingObjectMethod):
     """A mixin class that implements both TimedCache and CachingObjectMethod"""
+
     pass
 
 
@@ -105,15 +116,15 @@ class CachingObject(BaseObject, metaclass=CachingObjectMeta):
 
     # Magic Methods #
     # Construction/Destruction
-    def __init__(self):
+    def __init__(self) -> None:
         # Attributes #
-        self.is_cache = True
+        self.is_cache: bool = True
 
-        self._caches = self._caches_.copy()
+        self._caches: set[str] = self._caches_.copy()
 
     # Instance Methods #
     # Caches Operators
-    def get_caches(self):
+    def get_caches(self) -> set[str]:
         """Get all the caches in this object.
 
         Returns:
@@ -121,85 +132,126 @@ class CachingObject(BaseObject, metaclass=CachingObjectMeta):
         """
         for name in dir(self):
             attribute = getattr(type(self), name, None)
-            if (isinstance(attribute, BaseTimedCache) or (attribute is None and
-                isinstance(getattr(self, name), BaseTimedCache))):
+            if isinstance(attribute, BaseTimedCache) or (
+                attribute is None and isinstance(getattr(self, name), BaseTimedCache)
+            ):
                 self._caches.add(name)
 
         return self._caches
 
-    def enable_caching(self, exclude=set(), get_caches=False):
+    def enable_caching(self, exclude: set[str] | None = None, get_caches: bool = False) -> None:
         """Enables all caches to cache.
 
         Args:
             exclude: The names of the caches to exclude from caching.
-            get_caches: Determine if get_caches will be ran before setting the caches.
+            get_caches: Determines if get_caches will run before setting the caches.
         """
+        # Get caches if needed.
         if not self._caches or get_caches:
             self.get_caches()
 
-        for name in self._caches:
-            if name not in exclude:
-                getattr(self, name).set_caching_method()
+        # Exclude caches if needed.
+        if exclude is not None:
+            caches = self._caches.difference(exclude)
+        else:
+            caches = self._caches
 
-    def disable_caching(self, exclude=set(), get_caches=False):
+        # Enable caches in the set.
+        for name in caches:
+            getattr(self, name).set_caching_method()
+
+    def disable_caching(self, exclude: set[str] | None = None, get_caches: bool = False) -> None:
         """Disables all caches to cache.
 
         Args:
-            exclude: The names of the caches to exclude from not caching.
-            get_caches: Determine if get_caches will be ran before setting the caches.
+            exclude: The names of the caches to exclude from caching.
+            get_caches: Determines if get_caches will run before setting the caches.
         """
+        # Get caches if needed.
         if not self._caches or get_caches:
             self.get_caches()
 
-        for name in self._caches:
-            if name not in exclude:
-                getattr(self, name).set_caching_method(method="no_cache")
+        # Exclude caches if needed.
+        if exclude is not None:
+            caches = self._caches.difference(exclude)
+        else:
+            caches = self._caches
 
-    def timeless_caching(self, exclude=set(), get_caches=False):
+        # Disable caches in the set.
+        for name in caches:
+            getattr(self, name).set_caching_method(method="no_cache")
+
+    def timeless_caching(self, exclude: set[str] | None = None, get_caches: bool = False) -> None:
         """Sets all caches to have no expiration time.
 
         Args:
-            exclude: The names of the caches to exclude from not expiring.
-            get_caches: Determine if get_caches will be ran before setting the caches.
+            exclude: The names of the caches to exclude from caching.
+            get_caches: Determines if get_caches will run before setting the caches.
         """
+        # Get caches if needed.
         if not self._caches or get_caches:
             self.get_caches()
 
-        for name in self._caches:
-            if name not in exclude:
-                getattr(self, name).is_timed = False
+        # Exclude caches if needed.
+        if exclude is not None:
+            caches = self._caches.difference(exclude)
+        else:
+            caches = self._caches
 
-    def timed_caching(self, exclude=set(), get_caches=False):
+        # Disable expiration all caches in set.
+        for name in caches:
+            getattr(self, name).is_timed = False
+
+    def timed_caching(self, exclude: set[str] | None = None, get_caches: bool = False) -> None:
         """Sets all caches to have an expiration time.
 
         Args:
-            exclude: The names of the caches to exclude from expiring.
-            get_caches: Determine if get_caches will be ran before setting the caches.
+            exclude: The names of the caches to exclude from caching.
+            get_caches: Determines if get_caches will run before setting the caches.
         """
+        # Get caches if needed.
         if not self._caches or get_caches:
             self.get_caches()
 
-        for name in self._caches:
-            if name not in exclude:
-                getattr(self, name).is_timed = True
+        # Exclude caches if needed.
+        if exclude is not None:
+            caches = self._caches.difference(exclude)
+        else:
+            caches = self._caches
 
-    def clear_caches(self, exclude=set(), get_caches=False):
+        # Enable expiration for all caches in the set.
+        for name in caches:
+            getattr(self, name).is_timed = True
+
+    def clear_caches(self, exclude: set[str] | None = None, get_caches: bool = False) -> None:
         """Clears all caches in this object.
 
         Args:
-            exclude: The names of the caches to exclude from clearing.
-            get_caches: Determine if get_caches will be ran before clearing the caches.
+            exclude: The names of the caches to exclude from caching.
+            get_caches: Determines if get_caches will run before setting the caches.
         """
+        # Get caches if needed.
         if not self._caches or get_caches:
             self.get_caches()
 
-        for name in self._caches:
-            if name not in exclude:
-                getattr(self, name).clear_cache()
+        # Exclude caches if needed.
+        if exclude is not None:
+            caches = self._caches.difference(exclude)
+        else:
+            caches = self._caches
+
+        # Clear caches in the set.
+        for name in caches:
+            getattr(self, name).clear_cache()
 
 
 # Functions #
-def timed_single_cache_method(typed=False, lifetime=None, call_method="cache_call", collective=True):
+def timed_single_cache_method(
+    typed: bool = False,
+    lifetime: int | float | None = None,
+    call_method: AnyCallable | str = "caching_call",
+    collective: bool = True,
+) -> Callable[[AnyCallable], TimedSingleCacheMethod]:
     """A factory to be used a decorator that sets the parameters of timed single cache method factory.
 
     Args:
@@ -212,7 +264,7 @@ def timed_single_cache_method(typed=False, lifetime=None, call_method="cache_cal
         The parameterized timed single cache method factory.
     """
 
-    def timed_cache_method_factory(func):
+    def timed_cache_method_factory(func: AnyCallable) -> TimedSingleCacheMethod:
         """A factory for wrapping a method with a TimedSingleCacheMethod object.
 
         Args:
@@ -221,13 +273,23 @@ def timed_single_cache_method(typed=False, lifetime=None, call_method="cache_cal
         Returns:
             The TimeSingleCacheMethod object which wraps the given function.
         """
-        return TimedSingleCacheMethod(func, typed=typed, lifetime=lifetime,
-                                      call_method=call_method, collective=collective)
+        return TimedSingleCacheMethod(
+            func,
+            typed=typed,
+            lifetime=lifetime,
+            call_method=call_method,
+            collective=collective,
+        )
 
     return timed_cache_method_factory
 
 
-def timed_keyless_cache_method(typed=False, lifetime=None, call_method="cache_call", collective=True):
+def timed_keyless_cache_method(
+    typed: bool = False,
+    lifetime: int | float | None = None,
+    call_method: AnyCallable | str = "caching_call",
+    collective: bool = True,
+) -> Callable[[AnyCallable], TimedKeylessCacheMethod]:
     """A factory to be used a decorator that sets the parameters of timed keyless cache method factory.
 
     Args:
@@ -240,7 +302,7 @@ def timed_keyless_cache_method(typed=False, lifetime=None, call_method="cache_ca
         The parameterized timed keyless cache method factory.
     """
 
-    def timed_cache_method_factory(func):
+    def timed_cache_method_factory(func: AnyCallable) -> TimedKeylessCacheMethod:
         """A factory for wrapping a method with a TimedKeylessCacheMethod object.
 
         Args:
@@ -249,13 +311,24 @@ def timed_keyless_cache_method(typed=False, lifetime=None, call_method="cache_ca
         Returns:
             The TimeKeylessCacheMethod object which wraps the given function.
         """
-        return TimedKeylessCacheMethod(func, typed=typed, lifetime=lifetime,
-                                       call_method=call_method, collective=collective)
+        return TimedKeylessCacheMethod(
+            func,
+            typed=typed,
+            lifetime=lifetime,
+            call_method=call_method,
+            collective=collective,
+        )
 
     return timed_cache_method_factory
 
 
-def timed_cache_method(maxsize=None, typed=False, lifetime=None, call_method="cache_call", collective=True):
+def timed_cache_method(
+    maxsize: int | None = None,
+    typed: bool = False,
+    lifetime: int | float | None = None,
+    call_method: AnyCallable | str = "caching_call",
+    collective: bool = True,
+) -> Callable[[AnyCallable], TimedCacheMethod]:
     """A factory to be used a decorator that sets the parameters of timed cache method factory.
 
     Args:
@@ -269,7 +342,7 @@ def timed_cache_method(maxsize=None, typed=False, lifetime=None, call_method="ca
         The parameterized timed cache method factory.
     """
 
-    def timed_cache_method_factory(func):
+    def timed_cache_method_factory(func: AnyCallable) -> TimedCacheMethod:
         """A factory for wrapping a method with a TimedCacheMethod object.
 
         Args:
@@ -278,7 +351,13 @@ def timed_cache_method(maxsize=None, typed=False, lifetime=None, call_method="ca
         Returns:
             The TimeCacheMethod object which wraps the given function.
         """
-        return TimedCacheMethod(func, maxsize=maxsize, typed=typed, lifetime=lifetime,
-                                call_method=call_method, collective=collective)
+        return TimedCacheMethod(
+            func,
+            maxsize=maxsize,
+            typed=typed,
+            lifetime=lifetime,
+            call_method=call_method,
+            collective=collective,
+        )
 
     return timed_cache_method_factory
