@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """ circulardoublylinkedcontainer.py
-An abstract class which creates properties for this class automatically.
+A circular doubly linked container which is a fast and efficient way to store ordered data, especially if constantly
+changes size.
 """
 # Package Header #
-from ..__header__ import *
+from ..header import *
 
 # Header #
 __author__ = __author__
@@ -16,11 +17,13 @@ __email__ = __email__
 # Imports #
 # Standard Libraries #
 import copy
+from typing import Any, Optional
 
 # Third-Party Packages #
 
 # Local Packages #
-from ..baseobject import BaseObject
+from ..bases import BaseObject
+from ..bases.singlekwargdispatchmethod import singlekwargdispatchmethod
 
 
 # Definitions #
@@ -38,16 +41,23 @@ class LinkedNode(BaseObject):
         previous: The previous node.
         next_: The next node.
     """
+
     __slots__ = ["previous", "next", "data"]
 
     # Magic Methods #
     # Construction/Destruction
-    def __init__(self, data=None, previous=None, next_=None, init=True):
+    def __init__(
+        self,
+        data: Any | None = None,
+        previous: Optional["LinkedNode"] = None,
+        next_: Optional["LinkedNode"] = None,
+        init: bool = True,
+    ) -> None:
         # Attributes #
-        self.previous = self
-        self.next = self
+        self.previous: "LinkedNode" = self
+        self.next: "LinkedNode" = self
 
-        self.data = None
+        self.data: Any | None = None
 
         # Object Construction #
         if init:
@@ -55,7 +65,12 @@ class LinkedNode(BaseObject):
 
     # Instance Methods #
     # Constructors
-    def construct(self, data=None, previous=None, next_=None):
+    def construct(
+        self,
+        data: Any | None = None,
+        previous: Optional["LinkedNode"] = None,
+        next_: Optional["LinkedNode"] = None,
+    ) -> None:
         """Constructs this object.
 
         Args:
@@ -69,35 +84,36 @@ class LinkedNode(BaseObject):
         self.data = data
 
 
-class CirularDoublyLinkedContainer(BaseObject):
-    """A container that used nodes which at are doubly linked to one another to store data.
+class CircularDoublyLinkedContainer(BaseObject):
+    """A container that uses nodes which are doubly linked to one another to store data.
 
     Attributes:
         first_node: The first linked node in this container.
     """
+
     __slots__ = "first_node"
 
     # Magic Methods #
     # Construction/Destruction
-    def __init__(self):
+    def __init__(self) -> None:
         # Attributes #
-        self.first_node = None
+        self.first_node: LinkedNode | None = None
 
     @property
-    def is_empty(self):
+    def is_empty(self) -> bool:
         """Determines if this container is empty."""
         return self.first_node is None
 
     @property
-    def last_node(self):
+    def last_node(self) -> LinkedNode:
         """The last node in this container."""
         return self.first_node.previous
 
-    def __deepcopy__(self, memo=None, _nil=[]):
-        """The deepcopy magic method
+    def __deepcopy__(self, memo: dict | None = None, _nil=[]) -> "CircularDoublyLinkedContainer":
+        """Creates a deep copy of this object.
 
         Args:
-            memo (dict): A dictionary of user defined information to pass to another deepcopy call which it will handle.
+            memo: A dictionary of user defined information to pass to another deepcopy call which it will handle.
 
         Returns:
             A deep copy of this object.
@@ -113,29 +129,36 @@ class CirularDoublyLinkedContainer(BaseObject):
         return new_obj
 
     # Container Methods
-    def __len__(self):
-        """The method that gets this object's length."""
+    def __len__(self) -> int:
+        """Gets this object's length (number of nodes).
+
+        Returns:
+            The number of nodes in this object.
+        """
         return self.get_length()
 
-    def __getitem__(self, item):
-        """The method that allows index retrievals of stored items.
+    def __getitem__(self, item: int) -> LinkedNode:
+        """The method that allows index retrievals a node.
 
         Args:
             item: The index of the item to get.
+
+        Returns:
+            The node based on the index.
         """
         return self.get_item(item)
 
     # Bitwise Operators
-    def __lshift__(self, other):
-        """Shift the start of nodes to the left by an amount.
+    def __lshift__(self, other: int) -> None:
+        """Shifts the start of nodes to the left by an amount.
 
         Args:
             other: The number of nodes to shift to the left.
         """
         self.shift_left(other)
 
-    def __rshift__(self, other):
-        """Shift the start of nodes to the right by an amount.
+    def __rshift__(self, other: int) -> None:
+        """Shifts the start of nodes to the right by an amount.
 
         Args:
             other: The number of nodes to right to the left.
@@ -144,8 +167,12 @@ class CirularDoublyLinkedContainer(BaseObject):
 
     # Instance Methods #
     # Container Methods
-    def get_length(self):
-        """Get the number of nodes in this container."""
+    def get_length(self) -> int:
+        """Gets the number of nodes in this container.
+
+        Returns:
+            The number of nodes in this object.
+        """
         if self.is_empty:
             return 0
         else:
@@ -156,32 +183,43 @@ class CirularDoublyLinkedContainer(BaseObject):
                 length += 1
             return length
 
-    def get_item(self, index):
-        """Get a node based on its index from the start node."""
+    def get_item(self, index: int) -> LinkedNode:
+        """Gets a node based on its index from the start node.
+
+        Args:
+            index: The index of the item to get.
+
+        Returns:
+            The node based on the index.
+        """
         node = self.first_node
         i = 0
+
+        # Forward Indexing
         if index > 0:
             while i < index:
                 node = node.next
                 i += 1
+        # Reverse Indexing
         elif index < 0:
-            index * -1
+            index *= -1
             while i < index:
                 node = node.previous
                 i += 1
 
         return node
 
-    def append(self, data):
+    @singlekwargdispatchmethod("data")
+    def append(self, data: Any) -> LinkedNode:
         """Add a new node and data to the end of the container.
 
         Args:
             data: The data to add to the new last node.
+
+        Returns:
+            The LinkedNode added to the container.
         """
-        if isinstance(data, LinkedNode):
-            new_node = data
-        else:
-            new_node = LinkedNode(data)
+        new_node = LinkedNode(data)
 
         if self.first_node is None:
             self.first_node = new_node
@@ -191,17 +229,38 @@ class CirularDoublyLinkedContainer(BaseObject):
 
         return new_node
 
-    def insert(self, data, index):
-        """Add a new node and data at index within the nodes container.
+    @append.register
+    def _(self, data: LinkedNode) -> LinkedNode:
+        """Add a new node and data to the end of the container.
+
+        Args:
+            data: The data to add to the new last node.
+
+        Returns:
+            The LinkedNode added to the container.
+        """
+        new_node = data
+
+        if self.first_node is None:
+            self.first_node = new_node
+        else:
+            self.last_node.next = new_node
+            self.first_node.previous = new_node
+
+        return new_node
+
+    @singlekwargdispatchmethod("data")
+    def insert(self, data: Any, index: int) -> LinkedNode:
+        """Add a new node and data at index within the container.
 
         Args:
             data: The data to add to the new node.
             index: The place to insert the new node at.
+
+        Returns
+            The LinkedNode added to the container.
         """
-        if isinstance(data, LinkedNode):
-            new_node = data
-        else:
-            new_node = LinkedNode(data)
+        new_node = LinkedNode(data)
 
         if self.first_node is None:
             self.first_node = new_node
@@ -214,12 +273,37 @@ class CirularDoublyLinkedContainer(BaseObject):
 
         return new_node
 
-    def clear(self):
+    @insert.register
+    def _(self, data: LinkedNode, index: int) -> LinkedNode:
+        """Add a new node and data at index within the container.
+
+        Args:
+            data: The data to add to the new node.
+            index: The place to insert the new node at.
+
+        Returns
+            The LinkedNode added to the container.
+        """
+        new_node = data
+
+        if self.first_node is None:
+            self.first_node = new_node
+        else:
+            point = self.get_item(index=index)
+            new_node.next = point
+            new_node.previous = point.previous
+            new_node.previous.next = new_node
+            point.previous = new_node
+
+        return new_node
+
+    def clear(self) -> None:
         """Clears this container by removing the first node."""
+        del self.first_node
         self.first_node = None
 
     # Node Manipulation
-    def move_node_start(self, node):
+    def move_node_start(self, node: LinkedNode) -> None:
         """Move a node to the start of the container.
 
         Args:
@@ -228,7 +312,7 @@ class CirularDoublyLinkedContainer(BaseObject):
         self.move_node_end(node)
         self.first_node = node
 
-    def move_node_end(self, node):
+    def move_node_end(self, node: LinkedNode) -> None:
         """Move a node to the end of container.
 
         Args:
@@ -241,7 +325,7 @@ class CirularDoublyLinkedContainer(BaseObject):
         self.last_node.next = node
         self.first_node.previous = node
 
-    def move_node(self, node, index):
+    def move_node(self, node: LinkedNode, index: int) -> None:
         """Move a node to an index within the container.
 
         Args:
@@ -256,7 +340,7 @@ class CirularDoublyLinkedContainer(BaseObject):
         node.previous.next = node
         point.previous = node
 
-    def shift_left(self, value=1):
+    def shift_left(self, value: int = 1) -> None:
         """Shift the start of nodes to the left by an amount.
 
         Args:
@@ -270,7 +354,7 @@ class CirularDoublyLinkedContainer(BaseObject):
                 self.first_node = self.first_node.next
                 i += 1
 
-    def shift_right(self, value=1):
+    def shift_right(self, value: int = 1) -> None:
         """Shift the start of nodes to the right by an amount.
 
         Args:
